Sampling from a distribution of test results given H0

samplesH0(Nsample = 100, alpha, effectSize, pow)

Arguments

Nsample

It can be fixed or given by the user

alpha

level of significance (α = probability of type I error)

effectSize

the hypothesized effect size

pow

the desired power (1−β)

Value

Simulated likelihood ratios with p: Calculated PCDF values D|L(d=0|x) ? Tval: t value Nest: estimated group size ncp: non-centrality-parameter of the t-distribution representing H1 demps: obtained empirical effectsize

Examples

if (FALSE) {
samplesH0(Nsample = 100, alpha = 0.05, effectSize = 0.2, pow = 0.95)
}