Sampling from a distribution of test results given H1

samplesH1(Nsample = 100, alpha, effectSize, pow)

Arguments

Nsample

It can be fixed or given by the user

alpha

level of significance (α = probability of type I error)

effectSize

the hypothesized effect size

pow

the desired power (1−β)

Value

Simulated likelihood ratios prior to data collection with Tval: t value p: Calculated PCDF values D|L(d=0|x) ? Nest: estimated group size ncp: non-centrality-parameter of the t-distribution representing H1 Nsample: given sample size value d: given effectsize value

Examples

if (FALSE) {
samplesH1(Nsample = 100, alpha = 0.05, effectSize = 0.2, pow = 0.95)
}