samplesH1.RdSampling from a distribution of test results given H1
samplesH1(Nsample = 100, alpha, effectSize, pow)It can be fixed or given by the user
level of significance (α = probability of type I error)
the hypothesized effect size
the desired power (1−β)
Simulated likelihood ratios prior to data collection with Tval: t value p: Calculated PCDF values D|L(d=0|x) ? Nest: estimated group size ncp: non-centrality-parameter of the t-distribution representing H1 Nsample: given sample size value d: given effectsize value
if (FALSE) {
samplesH1(Nsample = 100, alpha = 0.05, effectSize = 0.2, pow = 0.95)
}